==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/MENUID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MENUID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MENUID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MENUDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MENUID_Type", propOrder = {
    "menucode",
    "menudescription"
})
public class MENUID_Type {

    @XmlElement(name = "MENUCODE", required = true)
    protected String menucode;
    @XmlElement(name = "MENUDESCRIPTION")
    protected String menudescription;

    /**
     * Obtient la valeur de la propriété menucode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMENUCODE() {
        return menucode;
    }

    /**
     * Définit la valeur de la propriété menucode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMENUCODE(String value) {
        this.menucode = value;
    }

    /**
     * Obtient la valeur de la propriété menudescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMENUDESCRIPTION() {
        return menudescription;
    }

    /**
     * Définit la valeur de la propriété menudescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMENUDESCRIPTION(String value) {
        this.menudescription = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/MENUID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MENUID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MENUID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MENUDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MENUID_Type", propOrder = {
    "menucode",
    "menudescription"
})
public class MENUID_Type {

    @XmlElement(name = "MENUCODE", required = true)
    protected String menucode;
    @XmlElement(name = "MENUDESCRIPTION")
    protected String menudescription;

    /**
     * Gets the value of the menucode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMENUCODE() {
        return menucode;
    }

    /**
     * Sets the value of the menucode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMENUCODE(String value) {
        this.menucode = value;
    }

    /**
     * Gets the value of the menudescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMENUDESCRIPTION() {
        return menudescription;
    }

    /**
     * Sets the value of the menudescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMENUDESCRIPTION(String value) {
        this.menudescription = value;
    }

}
